<!--报警率区域排名Top5-->
<template>
  <div class="ranking-alarm-rate-positions">
    <public-title title="报警率区域排名Top5" />
    <div class="chart-container">
      <div id="ranking-alarm-rate-positions-chart" style="width: 100%;height: 100%;" />
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {statisticsMaxPoliceArea} from '@/api/device/earlyWarningMonitoring'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'RankingAlarmRatePositions',
  components: {PublicTitle},
  data() {
    return {
      myChart: null,  // 图表实例对象
      chartData: []
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('ranking-alarm-rate-positions-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    async getChartData() {
      const {value} = await statisticsMaxPoliceArea('3')
      this.chartData = value
      this.$nextTick(_ => this.initEcharts())
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        grid: {
          left: '0',
          top: '0',
          right: '0',
          bottom: '0',
          containLabel: true
        },
        xAxis: {
          type: 'value',
          splitLine: {show: false},
          axisLabel: {show: false},
          axisTick: {show: false},
          axisLine: {show: false}
        },
        yAxis: [
          {
            type: 'category',
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {
              textStyle: {
                fontSize: 14,
                color: (name) => {
                  const index = this.chartData.findIndex(i => `${i.name}  ` === name)
                  let colorList = ['#ff6e79', '#ffb37b', '#ffda68']
                  return colorList[index] || '#606266'
                }
              }
            },
            data: this.chartData.map(i => `${i.name}  `),
            max: 4, // 关键：设置y刻度最大值，相当于设置总体行高
            inverse: true
          },
          {
            type: 'category',
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {
              textStyle: {
                fontSize: 14,
                color: '#999'
              },
              formatter: num => {
                if (num) return `   ${num} | ${(num / (this.chartData[0]?.num || 0) * 100).toFixed(0)}%`
              }
            },
            data: this.chartData.map(i => i.num),
            max: 4, // 关键：设置y刻度最大值，相当于设置总体行高
            inverse: true
          }
        ],
        series: [
          {
            name: '条',
            type: 'bar',
            barWidth: 30,
            data: this.chartData.map((item, index, arr) => {
              const [firstItem] = arr
              return (item.num / firstItem.num).toFixed(0) * 100
            }),
            barCategoryGap: 30,
            itemStyle: {
              normal: {
                barBorderRadius: 6,
                color: ({dataIndex}) => {
                  let colorList = ['#ff6e79', '#ffb37b', '#ffda68']
                  return colorList[dataIndex] || '#3eadfd'
                }
              }
            },
            zlevel: 1
          },
          {
            name: '进度条背景',
            type: 'bar',
            barGap: '-100%',
            barWidth: 30,
            data: this.chartData.map(_ => 100),
            color: '#e5e5e5',
            itemStyle: {
              normal: {
                barBorderRadius: 6
              },
              emphasis: {
                color: '#e5e5e5'
              }
            }
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.ranking-alarm-rate-positions {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }
}
</style>
